'---------------------------------------------------------------------
'      Name:   UFUNC4.INC   /  ersetzt:  alle vorigen UFUNCn.INC
'   Release:   4, Erweiterung von Release 3
'     Zweck:   INCLUDE-Datei mit Symbolen fuer
'              Uebliche USER-Function-Codes in Device-Drivern
'
' Copyright:   (C) Wilke Technology GmbH, 52018 Aachen, Germany
'---------------------------------------------------------------------
'
' Diese Datei spezifiziert die ueblichen USER-Function-Codes
' von Device-Treibern. Es gilt:
'
'       - Ein Device-Treiber kann, jeweils abgestimmt auf
'         seine Aufgabe, einen  S U B S E T  dieser Codes verwenden.
'
'       - Ein Device-Treiber kann ggf. ueber eigene, ganz spezielle
'         USER-Function-Codes verfuegen.
'
'       - Je nach Device-Treiber kann auch der Sekundaer-Adresse
'         die Aufgabe zukommen STEUER- und STATUS-Information
'         mit dem BASIC-Programm auszutauschen
'
'---------------------------------------------------------------------


'---------------------------------------------------------------------
' Allgemeine USER-Function-Codes:
'---------------------------------------------------------------------
'
' Grundsaetzlich koennen USER-Function-Codes benutzt werden um
'
'       - Einstellungen vorzunehmen:    write = PUT ...
'       - Zustaende / Status zu lesen:  read  = GET ...
'
'
' Je nach Device-Treiber koennen USER-Function-Codes:
'
'       - read only,
'       - write only,
'       - read + write
'
' eingesetzt werden.
'
'---------------------------------------------------------------------
'
' Benutzung der USER-Function-Codes in BASIC-Programmen:
'
'
' Write:       PUT #n, #SA, #UFC, <bytes>
'
'       #n   = Device-Nr
'       #SA  = Sekundaer-ADR
'       #UFC = USER-Function-Code  (siehe unten)
'    <bytes> = hier sind echte Parameter angegeben - oder
'              ein Dummy-Parameter, falls kein weiterer
'              Parameter gebraucht wird (z.B. Buffer-ERASE) !
'
'
'
' Read:        GET #n, #SA, #UFC, Bytes, VAR
'
'       #n   = Device-Nr
'       #SA  = Sekundaer-ADR
'       #UFC = USER-Function-Code  (siehe unten)
'      Bytes = Anzahl der zu lesenden Bytes
'        VAR = hier hin wird eingelesen !
'              Normalerweise = NUM Wert (LONG).
'              Falls STRING oder anders, siehe Hinweise
'
'---------------------------------------------------------------------
                                '(..) <----- read / write
#define UFC_INACTIVE         0H '(rw) inactive - keine Funktion !
#define UFCO_IBU_ERASE       1H '( w) Input-Buffer ERASE
#define UFCO_IBU_WRITE	     2H	'( w) write to Input Buffer (only LCD1.TDD)
#define UFCO_OBU_ERASE      21H '( w) Output-Buffer ERASE
                                '
#define UFCO_ERRC_RESET     41H '( w) RESET: Last OK-/WARN-/ERROR-Code
#define UFCO_ACTC_RESET     42H '( w) RESET: Last ACTION-Code
#define UFCO_LOSC_RESET     43H '( w) RESET: Last LOST-Data-Code
                                '
#define UFCI_IBU_FILL        1H '(r ) Input-Buffer Fuellung (Bytes)
#define UFCI_IBU_FREE        2H '(r ) Input-Buffer Free-Space (Bytes)
#define UFCI_IBU_VOL         3H '(r ) Input-Buffer Groesse (Bytes)
                                '
#define UFCI_OBU_FILL       21H '(r ) Output-Buffer Fuellung (Bytes)
#define UFCI_OBU_FREE       22H '(r ) Output-Buffer Free-Space (Bytes)
#define UFCI_OBU_VOL        23H '(r ) Output-Buffer Groesse (Bytes)
                                '
#define UFCI_LAST_ERRC      41H '(r ) Intern: Last OK-/WARN-/ERR-Code
#define UFCI_LAST_ACTC      42H '(r ) Intern: Last ACTION-Code
#define UFCI_LAST_LOSC      43H '(r ) Intern: Last LOST-Data-Code
                                '
#define UFCI_CPU_LOAD       44H '(r ) Melde CPU-Load (100%=10.000)
#define UFCI_DEV_VERS       63H '(r ) Dev-Dr.-Vers.: zB: 1016H = 1.016


'---------------------------------------------------------------------
' Zu Device-Driver:     ANALOG2.TDD
'---------------------------------------------------------------------
#define UFCO_AD2_CHAN       80H ' Setze Einzelkanal + Kanal-Nr
#define UFCO_AD2_RESO       81H ' Setze Aufloesung: 8,10,12-Bit
#define UFCO_AD2_INTEG      82H ' Integrations-Weite (nur 12 Bit):
                                ' 16, 32, 64 oder 128
#define UFCO_AD2_STOVL      83H ' "Stop-on-Buffer-Overflow"
                                ' 0=JA, n=nein
#define UFCO_AD2_CNT        84H ' Anzahl Messungen (je Kanal):
                                ' 0=endlos (nur FIFO), n=Anzahl
#define UFCO_AD2_PSCAL      85H ' Prescaler, teilt Basisfrequenz des
                                ' Treibers "TIMERA.TDD" ggf. herunter
#define UFCO_AD2_STOP       86H ' Stop AD-Sampling
#define UFCO_AD2_GROF       87H ' Setze Growth-Flag (nur fuer STRING)
                                ' 0 = spontane Groessen-Zuweisung
                                ' <>0 = kontinuierliche Erhoehung
#define UFCO_AD2_SCAN       88H ' Setze Mehrkanalmodus:
                                ' 1, 2, 3 oder 4 Kanaele gleichzeitig
#define UFCO_AD2_ISAMP      89H ' Integral-Samples: jede wievielte
                                ' Messung soll genommen werden
                                ' (nur fuer 12-Bit Messung).
#define UFCO_AD2_PSCIMM     8FH ' setze Prescaler waehrend der Messung
#define UFCO_AD2_DFLT       2EH ' Setze auf Standardwerte


'---------------------------------------------------------------------
' Zu Device-Driver:     ANALOG2.TDD
'---------------------------------------------------------------------
#define UFCO_AD3_FACTOR     90H ' Setze Skalierungsfaktor f. Messwert


'---------------------------------------------------------------------
' Zu Device-Driver:     CAN1.TDD
'---------------------------------------------------------------------
' fuer GET
#define UFCI_CAN_MODE       98H ' lies CAN-Register MODE (CTRL)
#define UFCI_CAN_STAT       99H ' lies CAN-Register STAT
#define UFCI_CAN_CODE       9AH ' setze CAN-Register CODE
#define UFCI_CAN_MASK       9BH ' lies CAN-Register MASK
#define UFCI_CAN_ALC        9CH ' lies CAN-Register arbitration lost
#define UFCI_CAN_ECC        9DH ' lies CAN-Register error code capture
#define UFCI_CAN_RXERR      9EH ' lies CAN-Register rx error counter
#define UFCI_CAN_TXERR      9FH ' lies CAN-Register tx error counter
#define UFCI_CAN_RMC       0A0H ' lies CAN-Register rx message counter
#define UFCI_CAN_BUSY      0A1H ' lies CAN busy Status


' fuer PUT
#define UFCO_CAN_MODE       88H ' setze CAN-Register MODE (CTRL)
#define UFCO_CAN_OUTCTRL    89H ' setze CAN-Register OUTCTRL
#define UFCO_CAN_CODE       8AH ' setze CAN-Register CODE
#define UFCO_CAN_MASK       8BH ' setze CAN-Register MASK
#define UFCO_CAN_BUSTIM0    8CH ' setze CAN-Register BUSTIM0
#define UFCO_CAN_BUSTIM1    8DH ' setze CAN-Register BUSTIM1
#define UFCO_CAN_EWL        8FH ' setze CAN-Register EWL
#define UFCO_CAN_RESET     0B0H ' soft-reset CAN chip
#define UFCO_CAN_RESRM     0C1H ' setze CAN-Chip in RUN-Mode


'---------------------------------------------------------------------
' Zu Device-Driver:     CNT1_xxx.TDD
'---------------------------------------------------------------------
#define UFCO_CNT_EDGE       83H ' Setze Flankenzaehlung: 0 = steigend,
                                ' 1 = fallend, 2 = beide
#define UFCO_CNT_STOP       85H ' Stoppe Zaehlung der Flanken


'---------------------------------------------------------------------
' Zu Device-Driver:     ENC1_xx.TDD
'---------------------------------------------------------------------
#define UFCO_WEIGHTTAB      80H ' Setze Gewichtungstabelle
#define UFCO_SCALEFCT       81H ' Setze Scalierungsfaktor
#define UFCO_ENC_STOP       85H ' Stoppe die Zaehlung
#define UFCO_ENC_START      86H ' Starte die Zaehlung
#define UFCO_ENC_DIR        87H ' Setze Drehrichtung pos./neg.


'---------------------------------------------------------------------
' Zu Device-Driver:     FREQ1_xx.TDD
'---------------------------------------------------------------------
#DEFINE UFCO_FRQ_GATE     81H ' setze Gate-Time in Anzahl TIMERA-Ticks
                              ' Bereich 6...nnnn
#DEFINE UFCO_FRQ_EDGE     83H '  Set Trigger-Edge: 0=(+), 1=(-), 2=NEXT
#DEFINE UFCO_FRQ_CAL      86H ' setze Kalibrierfactor
                              ' Kalibriere Frequenzzeitbasis:
                              ' 0,1000H ... 10,0000H
                              ' Die gemessene Frequenz (mHz) wird
                              ' mit dieser 32-Bit-Zahl multipliziert
#DEFINE UFCO_FRQ_STOP     95H ' Stoppe FREQU-Messung: DUMMY-Parameter

'---------------------------------------------------------------------
' Zu Device-Driver:     LCD1.TDD
'---------------------------------------------------------------------
'       LC-Display-Typen mit HD44780-Prozessor (fuer INSTALL_DEVICE)
'
'    LCD-Typ            Nr      Zeilen x Spalten, Refresh-Mode
'---------------------------------------------------------------------
#define LCD1_1_8         1      ' 1 x  8, 1: 8  Hitachi 44780
#define LCD1_1_12        2      ' 1 x 12, 1: 8        "
#define LCD1_1_16        3      ' 1 x 16, 1: 8        "
#define LCD1_1_20        4      ' 1 x 20, 1: 8        "
#define LCD1_1_40        5      ' 1 x 40, 1: 8        "
#define LCD1_2_8         6      ' 2 x  8, 1: 8        "
#define LCD1_2_12        7      ' 2 x 12, 1: 8        "
#define LCD1_2_16        8      ' 2 x 16, 1: 8        "
#define LCD1_2_20        9      ' 2 x 20, 1: 8        "
#define LCD1_2_40       10      ' 2 x 40, 1: 8        "
#define LCD1_4_20       11      ' 4 x 20, 1: 8        "
#define LCD2_2_8        12      ' 2 x  8, 1:16        "
#define LCD2_2_12       13      ' 2 x 12, 1:16        "
#define LCD2_2_16       14      ' 2 x 16, 1:16        "
#define LCD2_2_20       15      ' 2 x 20, 1:16        "
#define LCD2_2_40       16      ' 2 x 40, 1:16        "
#define LCD2_4_20       17      ' 4 x 20, 1:16  (default)
#define LCD2_2_24       18      ' 2 x 24, 1:16        "
#define LCD2_4_16       19      ' 4 x 16, 1:16        "

#define LCD3_4_24	20	' 4 x 24, 1:??  NJU 6426  (New Japan Radio Co)  <===  ab 28-SEPT-2000  / Vers. Vers. 1.01h
#define LCD3_2_8	21	' 2 x  8, 1:??  NJU 6426  (New Japan Radio Co)  <===  ab 28-SEPT-2000  / Vers. Vers. 1.01h
				' 1 x 16, 1:??  NJU 6426  (New Japan Radio Co)  <===  ab 28-SEPT-2000  / Vers. Vers. 1.01h
#define LCD3_2_16	22	' 2 x 16, 1:??  NJU 6426  (New Japan Radio Co)  <===  ab 28-SEPT-2000  / Vers. Vers. 1.01h
#define LCD3_2_24	23	' 2 x 24, 1:??  NJU 6426  (New Japan Radio Co)  <===  ab 28-SEPT-2000  / Vers. Vers. 1.01h
#define LCD3_2_32	24	' 2 x 32, 1:??  NJU 6426  (New Japan Radio Co)  <===  ab 28-SEPT-2000  / Vers. Vers. 1.01h
#define LCD3_2_40	25	' 2 x 40, 1:??  NJU 6426  (New Japan Radio Co)  <===  ab 28-SEPT-2000  / Vers. Vers. 1.01h
#define LCD3_4_8	26	' 4 x  8, 1:??  NJU 6426  (New Japan Radio Co)  <===  ab 28-SEPT-2000  / Vers. Vers. 1.01h
#define LCD3_4_16	27	' 4 x 16, 1:??  NJU 6426  (New Japan Radio Co)  <===  ab 28-SEPT-2000  / Vers. Vers. 1.01h
#define LCD3_4_20	28	' 4 x 20, 1:??  NJU 6426  (New Japan Radio Co)  <===  ab 28-SEPT-2000  / Vers. Vers. 1.01h

#define LCD3_4_32_TEST  29	' 4 x 32   N=0, E1=0, E0=0    NJU 6426  (New Japan Radio Co)  Tests mit neuen LCDs

#define LCD4_4_20	37	' 4 x 20, 1:??  EA DIP204-4 Electronic Assembly  <===  ab 17-Feb-2004
#define LCD4_3_16	38	' 3 x 16, 1:??  EA DOGM163x-A Electronic Assembly <==  ab  8-Dez-2004  / Engel


#define UFCO_KB_ECHO       082H  ' Setze Echofunktion (JA/NEIN)
#define UFCO_CTRL_OUT	   083H  ' sende direkt 1...n Kommando-Bytes an LCD, "LCD1.tdd" V1.01n 
#define UFCO_LCD_RESET     0B0H  ' re-initialisiere LCD (auch 6963)


'---------------------------------------------------------------------
' Zu Device-Driver:     LCD-6963.TDD
'---------------------------------------------------------------------
'       LC-Display-Typen mit T6963C-Prozessor (fuer INSTALL_DEVICE)
'
'       LCD-Typ         Nr       Pixel (SxZ)   Font    Text (ZxS)  RAM
'---------------------------------------------------------------------
#define LCD_TGR_BW1	 1	' 128 x  64    8 x 8     8 x 16
#define LCD_TGR_BW2	 2	' 128 x 128    8 x 8    16 x 16
#define LCD_TGR_BW3	 3	' 240 x 128    8 x 8    16 x 30    32k
#define LCD_TGR_BW4	 4	' 240 x 128    8 x 8    16 x 30     8k
#define LCD_TGR_BW5	 5	' 192 x 128    8 x 8    16 x 24
#define LCD_TGR_BW6	 6	' 240 x 128    6 x 8    16 x 40    32k
#define LCD_TGR_BW7	 7	' 128 x  64    6 x 8     8 x 21
#define LCD_TGR_BW8	 8	' 192 x 128    6 x 8    16 x 32
#define LCD_TGR_BW9	 9	' 128 x 128    8 x 8    16 x 16
#define LCD_TGR_BW10	10	' 128 x 128    6 x 8    16 x 21
#define LCD_TGR_BW11	11	' 240 x 128    6 x 8    16 x 40     8k


#define UFCO_LCD_TYPE       90H ' Setze LCD-Typ
#define UFCO_LCD_TXTSIZ     9CH ' Setze Anzahl Zeilen und Spalten
                                ' Anz. Zeilen, Zeichen/Zeile "<16><40>"
                                ' dann RESET geben
#define UFCO_LCD_LINE       9DH ' Verhalten am
                                ' Zeilenende: 0 = naechste Zeile,
                                ' 1 = gleiche Zeile, 2 = stop
                                ' Bildschirmende: 0 = Bildschirmanfang
                                ' 1 = Anfang letzte Zeile, 2 = stop
#define UFCO_LCD_PARAM      9EH ' Setze LCD Parameter wie in INSTALL
#define UFCO_LCD_PWR        9FH ' setze CPU-Power 4...128
#define UFCO_LCD_LOAD       9FH ' setze CPU-Power 4...88
'#define UFCO_LCD_RESET     0B0H ' re-initialisiere LCD


'---------------------------------------------------------------------
' Zu Device-Driver:     PLSIN1.TDD
'---------------------------------------------------------------------
#define UFCO_IPL_RNG       80H  ' Setze neuen Zeitbasis-Bereich
#define UFCO_IPL_STOP      85H  ' Stoppe die Messung
#define UFCI_IPL_OVL      0A0H  ' Lies Anzahl der Ueberlaeufe


'---------------------------------------------------------------------
' Zu Device-Driver:     PLSI2_xx.TDD
'---------------------------------------------------------------------
#define UFCO_PLS_SIGN       80H ' 16-Bit-Wert: 0 = mit, 1 = ohne
                                ' Vorzeichen
#define UFCO_PLS_STOP       85H ' Stoppt die Messung


'---------------------------------------------------------------------
' Zu Device-Driver:     PLSOUT1.TDD
'---------------------------------------------------------------------
#define UFCO_OPL_RNG        90H ' Setze neuen Zeitbasis-Bereich
#define UFCO_OPL_CNT        91H ' Setze neue Anzahl Pulse
                                ' setze -1 um Ausgabe zu stoppen
                                ' Pulse werden nicht gekappt

#define UFCI_OPL_STAT      0B0H ' Lese Anzahl der verbleibenden Pulse


'---------------------------------------------------------------------
' Zu Device-Driver:     PLSO2.TDD
'---------------------------------------------------------------------
#define UFCO_PO2_LEVEL      80H ' Setzt Ruhepegel am Pulsausgabepin
#define UFCO_PO2_STOP       85H ' Stoppt Pulsausgabe: 0 = sofort,
                                ' 1 = naechstes hi, 2 = naechstes low
#define UFCO_OPL_ADJ        86H ' Setzt waehrend Ausgabe neue Anzahl
                                ' und loescht Reload-Puffer
#define UFCI_OPL_REST       93H ' Lese Anzahl der verbleibenden Pulse


'---------------------------------------------------------------------
' Zu Device-Driver:     PWM1.TDD
'---------------------------------------------------------------------
'
' Aufloesung:              RESOL_6BIT    RESOL_7BIT    RESOL_8BIT
'                            6-Bit:         7-Bit:        8-Bit:
'                           <----->        <----->       <----->
'  FREQU_LO:     slow         5 kHz        2.5 kHz       1.2 kHz
'  FREQU_MED:    medium      20 kHz         10 kHz         5 kHz
'  FREQU_HI:     high        80 kHz         40 kHz        20 kHz
'
'---------------------------------------------------------------------
'
' UFCO_DEV_OPT2  =  PWM-Frequency in Hz (long)   - read only
'
'                           1200 =  1.2 kHz    Frequenz-Werte
'                           2500 =  2.5 kHz    wie sie bei dieser
'                           5000 =    5 kHz    Aufloesung sind
'                          10000 =   10 kHz    in Hz (ca.)
'                          20000 =   20 kHz
'                          40000 =   40 kHz
'                          80000 =   80 kHz
'
'---------------------------------------------------------------------
' fuer PUT
'---------------------------------------------------------------------
#define UFCO_PWM_SPEED      90H ' PWM-Speed
#define UFCO_PWM_RESO       91H ' PWM-Aufloesung
'---------------------------------------------------------------------
' fuer GET
'---------------------------------------------------------------------
#define UFCI_PWM_SPEED      90H ' PWM-Speed
#define UFCI_PWM_RESO       91H ' PWM-Aufloesung
#define UFCI_PWM_FREQU      92H ' PWM-Frequenz
'---------------------------------------------------------------------
' Parameter - Index
'---------------------------------------------------------------------
#define PWM_SPEED_LO          2 ' Index: Speed is LOW
#define PWM_SPEED_MED         1 ' Index: Speed is MEDIUM
#define PWM_SPEED_HI          0 ' Index: Speed is HIGH

#define PWM_FREQU_LO          2 ' Index: Freq is LOW
#define PWM_FREQU_MED         1 ' Index: Freq is MEDIUM
#define PWM_FREQU_HI          0 ' Index: Freq is HIGH

#define PWM_RESO_6BIT         0 ' Index: Aufloesung is 6-Bit
#define PWM_RESO_7BIT         1 ' Index: Aufloesung is 7-Bit
#define PWM_RESO_8BIT         2 ' Index: Aufloesung is 8-Bit


'---------------------------------------------------------------------
' Zu Device-Driver:     PWM2.TDD
'---------------------------------------------------------------------
'
' Aufloesung:              RESOL_6BIT    RESOL_7BIT    RESOL_8BIT
'                            6-Bit:         7-Bit:        8-Bit:
'                           <----->        <----->       <----->
'  FREQU_LO:     slow         5 kHz        2.5 kHz       1.2 kHz
'  FREQU_MED:    medium      20 kHz         10 kHz         5 kHz
'  FREQU_HI:     high        80 kHz         40 kHz        20 kHz
'
'---------------------------------------------------------------------
'
' PWM-Frequency in Hz (long)   - read only
'
'                           1200 =  1.2 kHz    Frequenz-Werte
'                           2500 =  2.5 kHz    wie sie bei dieser
'                           5000 =    5 kHz    Aufloesung sind
'                          10000 =   10 kHz    in Hz (ca.)
'                          20000 =   20 kHz
'                          40000 =   40 kHz
'                          80000 =   80 kHz
'
'---------------------------------------------------------------------
' fuer PUT
'---------------------------------------------------------------------
#define UFCO_PW2_FREQU      90H ' PWM2-Traegerfrequenz
#define UFCO_PW2_RESO       91H ' PWM2-Aufloesung
#define UFCO_PW2_PSCAL      92H ' PWM2-Prescaler
#define UFCO_PW2_OVS        93H ' PWM2-Anzahl Zwischenwerte
#define UFCO_PW2_STOP       9AH ' PWM-Output anhalten
#define UFCO_PW2_DFLT       2EH ' Einstellung auf Standardwerte
#define UFCO_PW2_PSCIMM     9FH ' setze Prescaler waehrend PWM2 laeuft
'---------------------------------------------------------------------
' fuer GET
'---------------------------------------------------------------------
#define UFCI_PW2_FREQU      90H ' PWM2-Frequenz
#define UFCI_PW2_ACT        91H ' PWM2-Ausgabe noch aktiv? <>0=ja
#define UFCI_PW2_RLD        92H ' PWM2-Reload-State
#define UFCI_PW2_REST       93H ' PWM2 Restdaten (noch auszugeben)


'---------------------------------------------------------------------
' Zu Device-Driver:     RTC1.TDD
'---------------------------------------------------------------------
#define UFCI_RTC_STAT0     0A0H ' RTC Option Status:
                                ' Antworten des Treibers:
#define RTC_INITIAL           0 ' gleich nach Power-ON
#define RTC_INSTALLING        1 ' Installation dauert noch an
#define RTC_NO_RTC            2 ' keine RTC-Hardware vorhanden
#define RTC_PRESENT           3 ' OK, RTC-Hardware anwesend
#define RTC_RETRY             4 ' Suche nach RTC wiederholen
                                '-------------------------------------
#define UFCI_RTC_STAT1     0A1H ' RTC Device Status:
                                ' Antworten des Treibers:
#define RTC_READY             0 ' Ready
#define RTC_BUSY              1 ' Busy
                                '-------------------------------------


'---------------------------------------------------------------------
' Zu Device-Driver:     SER1B_xx.TDD
'---------------------------------------------------------------------
#define UFCO_SET_SERIAL     5EH ' Setze serielle Parameter
                                ' 1.Byte=Baudrate-Index   (low-Order)
                                ' 2.Byte=Data-/Parity-Ndx (high-Order)
                                ' 3.Byte=Receive on Error (high-Order)
                                '        00=ja, FF=nein
#define UFCO_SET_ISEP       80H ' Setze neue Separatorzeichen (INPUT)
#define UFCO_RES_ISEP       81H ' Loesche Separatorzeichen (INPUT)
#define UFCO_SER_ECHO       82H ' Setze Echofunktion (JA/NEIN)
#define UFCO_SER_RTS        85H ' Setze RTS0 auf:
                                ' 0 = nicht bereit
                                ' 1 = bereit

#define UFCI_SER_STAT       90H ' WORD-low-Byte = Empf.fehler
                                ' WORD-high-Byte = Pufferueberlaeufe

'---------------------------------------------------------------------
' neue UFCs fuer den 9-Bit-Betrieb
#define UFCO_SER_9BIT       83h ' setze Bit 9 zu 1 oder 0
#define UFCO_SER_9ADR       84h ' setze Adresse dieses Moduls
                                ' 00...FFh
                                ' Adressen haben das 9. Bit gesetzt
                                ' und erscheinen nicht im Puffer
                                ' Datenempfang beginnt, nachdem die
                                ' gueltige Adresse empfangen wurde
                                ' und endet mit dem Empfang einer
                                ' ungueltigen 9-Bit-Adresse

#define UFCI_SER_9STS       91h ' Status:
                                ' 0=warte auf Adresse
                                ' 1=empfange
#define UFCI_SER_9ADR       92h ' zuletzt empfangene Adresse


'---------------------------------------------------------------------
' Zu Device-Driver:     SER4_K1.TDD
' DACC = direct access (direckter Zugriff auf String)
'---------------------------------------------------------------------
#DEFINE INT_YES               0 ' Modus int. Buffer mit Fehlerzeichen
#DEFINE INT_NO                1 ' Modus int. Buffer ohne Fehlerzeichen
#DEFINE DACC                  2 ' Modus DACC-Buffer

                                ' Die folgenden Defines beziehen sich
                                ' auf Sekundaer-Adressen von SER4
                                ' Ein PUT auf die Sek.Adr. bewirkt:
#DEFINE DACC0_TX            10h ' DACC seriell senden auf Kanal 0
#DEFINE DACC1_TX            11h ' DACC seriell senden auf Kanal 1
#DEFINE DACC0_TRLD          12h ' DACC ser. senden auf K. 0, reload
#DEFINE DACC1_TRLD          13h ' DACC ser. senden auf K. 1, reload
#DEFINE DACC0_RX            14h ' DACC seriell empfangen auf Kanal 0
#DEFINE DACC1_RX            15h ' DACC seriell empfangen auf Kanal 1
#DEFINE DACC0_RRLD          16h ' DACC ser. empfangen auf K. 0, reload
#DEFINE DACC1_RRLD          17h ' DACC ser. empfangen auf K. 1, reload

                                ' GET = lies von Sek.-Adr. 0
#DEFINE UFCI_SER4_STAT      93H ' Status: ser. Senden/Empfangen
                                ' 4 Bytes betreffend tx DACC-String
                                ' low word: Anzahl noch ungesendeter
                                '               Bytes im Sendestring
                                ' high word: Tx-Reload-Stringlaenge

                                ' GET = lies von Sek.-Adr. 1
                                ' 4 Bytes betreffend rx DACC-String
                                ' low word: Anzahl freier Bytes
                                '             im Empfangsstring
                                ' high word: Rx-Reload-Stringlaenge

                                ' GET = lies von Sek.-Adr. 2
                                ' 8 Bytes betreffend tx+rx DACC-String
                                ' low word-1: Anzahl noch ungesendeter
                                '               Bytes im Sendestring
                                ' word-2: Tx-Reload-Stringlaenge
                                ' word-3: Anzahl freier Bytes
                                '           im Empfangsstring
                                ' high word-4: Rx-Reload-Stringlaenge

                                ' PUT auf Sek-Adr. 0
#DEFINE UFCO_SER4_GROF      87H ' setze 'growth flag' fuer DACC-String
                                ' 2: Groesse nicht veraendern
                                ' 3: String waechst, wenn noetig


'---------------------------------------------------------------------
' Zu Device-Driver:     TMEM_xx.TDD
'---------------------------------------------------------------------
#define UFCI_TMEM_OVL      0A0H ' TouchMemory Overflow Status (0=ok)
#define UFCI_TMEM_PRS      0A1H ' TouchMemory Praesenz (0=ok)


'---------------------------------------------------------------------
' USER function codes:    options for  O U T P U T - operations
'---------------------------------------------------------------------
#define UFCO_DEV_IOPT0   80H ' Input-Setting: Option-0 (zB: Baudrate,
#define UFCO_DEV_IOPT1   81H ' Input-Setting: Option-1  Tast-Verh.,
#define UFCO_DEV_IOPT2   82H ' Input-Setting: Option-2  Zeit-Basis,
#define UFCO_DEV_IOPT3   83H ' Input-Setting: Option-3  ...)
#define UFCO_DEV_IOPT4   84H ' Input-Setting: Option-4 <je nach
#define UFCO_DEV_IOPT5   85H ' Input-Setting: Option-5  Dev-Driver>
#define UFCO_DEV_IOPT6   86H ' Input-Setting: Option-6
#define UFCO_DEV_IOPT7   87H ' Input-Setting: Option-7
                             '
#define UFCO_DEV_OOPT0   90H ' Output-Setting: Option-0 (zB: Baudrate,
#define UFCO_DEV_OOPT1   91H ' Output-Setting: Option-1  Tast-Verh.,
#define UFCO_DEV_OOPT2   92H ' Output-Setting: Option-2  Zeit-Basis,
#define UFCO_DEV_OOPT3   93H ' Output-Setting: Option-3  ...)
#define UFCO_DEV_OOPT4   94H ' Output-Setting: Option-4 <je nach
#define UFCO_DEV_OOPT5   95H ' Output-Setting: Option-5  Dev-Driver>
#define UFCO_DEV_OOPT6   96H ' Output-Setting: Option-6
#define UFCO_DEV_OOPT7   97H ' Output-Setting: Option-7


'---------------------------------------------------------------------
' USER function codes:    options for  I N P U T - operations
'---------------------------------------------------------------------
#define UFCI_DEV_IOPT0   80H ' Input-Setting: Option-0 (zB: Baudrate,
#define UFCI_DEV_IOPT1   81H ' Input-Setting: Option-1  Tast-Verh.,
#define UFCI_DEV_IOPT2   82H ' Input-Setting: Option-2  Zeit-Basis,
#define UFCI_DEV_IOPT3   83H ' Input-Setting: Option-3  ...)
#define UFCI_DEV_IOPT4   84H ' Input-Setting: Option-4 <je nach
#define UFCI_DEV_IOPT5   85H ' Input-Setting: Option-5  Dev-Driver>
#define UFCI_DEV_IOPT6   86H ' Input-Setting: Option-6
#define UFCI_DEV_IOPT7   87H ' Input-Setting: Option-7
                             '
#define UFCI_DEV_OOPT0   90H ' Output-Setting: Option-0 (zB: Baudrate,
#define UFCI_DEV_OOPT1   91H ' Output-Setting: Option-1  Tast-Verh.,
#define UFCI_DEV_OOPT2   92H ' Output-Setting: Option-2  Zeit-Basis,
#define UFCI_DEV_OOPT3   93H ' Output-Setting: Option-3  ...)
#define UFCI_DEV_OOPT4   94H ' Output-Setting: Option-4 <je nach
#define UFCI_DEV_OOPT5   95H ' Output-Setting: Option-5  Dev-Driver>
#define UFCI_DEV_OOPT6   96H ' Output-Setting: Option-6
#define UFCI_DEV_OOPT7   97H ' Output-Setting: Option-7


'---------------------------------------------------------------------
' Function-Codes f. Status-Info + CTRL-Settings    (Input + Output)
'---------------------------------------------------------------------
#define UFCI_DEV_ISTAT0  0A0H ' Input-Status: Option-0
#define UFCI_DEV_ISTAT1  0A1H ' Input-Status: Option-1  Ob und welche
#define UFCI_DEV_ISTAT2  0A2H ' Input-Status: Option-2  USER-Functions
#define UFCI_DEV_ISTAT3  0A3H ' Input-Status: Option-3  verwendet
#define UFCI_DEV_ISTAT4  0A4H ' Input-Status: Option-4  werden haengt
#define UFCI_DEV_ISTAT5  0A5H ' Input-Status: Option-5  vom Device-
#define UFCI_DEV_ISTAT6  0A6H ' Input-Status: Option-6  Treiber ab
#define UFCI_DEV_ISTAT7  0A7H ' Input-Status: Option-7
                              '
#define UFCI_DEV_OSTAT0  0B0H ' Output-Status: Option-0
#define UFCI_DEV_OSTAT1  0B1H ' Output-Status: Option-1
#define UFCI_DEV_OSTAT2  0B2H ' Output-Status: Option-2
#define UFCI_DEV_OSTAT3  0B3H ' Output-Status: Option-3
#define UFCI_DEV_OSTAT4  0B4H ' Output-Status: Option-4
#define UFCI_DEV_OSTAT5  0B5H ' Output-Status: Option-5
#define UFCI_DEV_OSTAT6  0B6H ' Output-Status: Option-6
#define UFCI_DEV_OSTAT7  0B7H ' Output-Status: Option-7

